==> haskell-aeson-diff-1.1.0.13-64.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-ETodEDgGFL6314vd22HatE
key:                  aeson-diff-1.1.0.13-ETodEDgGFL6314vd22HatE
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  bced5a2e7c065ddf3b4822e79a83d8b0
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-ETodEDgGFL6314vd22HatE
depends:
    aeson-2.1.2.1-Hk9KEBD3XM0EgL24zrVKOB base-4.15.1.0
    bytestring-0.10.12.1
    edit-distance-vector-1.0.0.4-JeroPlxkdHPDE51o9sj2wK
    scientific-0.3.7.0-Ckr5dpk95htIlJhJkgIjmf text-1.2.5.0
    vector-0.13.0.0-BjxWK3IuCPM3Cpg6TT9ukI

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.13-116-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-KRLDJcpnFcvGldSmwccOfc
key:                  aeson-diff-1.1.0.13-KRLDJcpnFcvGldSmwccOfc
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  f7f6eef0a88964da0a2fcc13be24edbf
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-KRLDJcpnFcvGldSmwccOfc
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0
    edit-distance-vector-1.0.0.4-gg0OQAEdnLG38aZ1pJHJ5
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
